"""
Extractors
----------

Extractors are a way to build structured datasets that you can use from tags within Documents

"""
from .extractors import TaggedTableToDataStore
